@@ -89,6 +89,13 @@ case "$1" in
             fi
         fi
 
+        PERMAPASS=/etc/benno-web/permalink.pass
+        if [ ! -f $PERMAPASS ];then
+            cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 20 | head -n 1 > $PERMAPASS
+            chgrp www-data $PERMAPASS
+            chmod g=r,o= $PERMAPASS
+        fi
+
         # Auth.d
         if [ ! -f /etc/benno-web/auth.conf ];then
             echo "# benno_auth.d configuration file" >> /etc/benno-web/auth.conf
@@ -120,7 +127,7 @@ case "$1" in
     ;;
 esac
 
-invoke-rc.d apache2 force-reload
+[ -x /etc/init.d/apache2 ] && invoke-rc.d apache2 restart
 
 
 exit 0
