@@ -307,6 +307,9 @@ class Application extends ApplicationConfig
                                      $this->config['DBPASS'],$this->config['DBHOST'],
                                      $this->config['DATABASE']);
         }
+        else {
+            $this->DB = new DBAccess('sqlite:////var/lib/benno-web/bennoweb.sqlite');
+        }
 
 
     }
@@ -392,6 +395,27 @@ class Application extends ApplicationConfig
     }
 
 
+    /**
+     * Get array of config values
+     *
+     * @access public
+     * @param string $name
+     * @param string $default (optional)
+     * @return arrray $params
+     */
+    function getConfigList ($name,$default=false)
+    {
+        if (isset($this->config[$name])) {
+            return  preg_split('/,(\s+)?/',$this->config[$name]);
+        }
+        else if ($default) {
+            return $default;
+        }
+        else {
+            return false;
+        }
+    }
+
 
     /**
      * accessLevel
