@@ -31,24 +31,24 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 
-$permaId = $App->getParam('id');
+$permalink = $App->getParam('id');
 
 if ($App->accessLevel() < 1) {      // user not authenticated
-    $App->setSession('permaId',$permaId);
+    $App->setSession('permalink',$permalink);
     $App->setSession('LOGIN_REDIRECT','permaLink');
     $App->redirect('default');
     // end of request
 }
 
 // Redirect from Login
-if (!$permaId) {
-    $permaId = $App->getSession('permaId');
+if (!$permalink) {
+    $permalink = $App->getSession('permalink');
     $App->unsetSession('LOGIN_REDIRECT');
 }
 
-list($bennoId,$permaArchive) = explode('@',base64_decode($permaId),2);
-
-$PermaQuery = new Query($permaId,$permaArchive,$bennoId);
+$PermaId = new PermaId();
+list($bennoId,$permaArchive) = $PermaId->decrypt($permalink);
+$PermaQuery = new Query($permalink,$permaArchive,$bennoId);
 $PermaQuery->type = 'RepoPath';
 
 $ExtQuery    = new Query('empty');
